#  MIT License

#  Copyright (c) 2023 X-Noid

#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:

#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.

#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.

class Scrape:
    
    def __init__(self, api):
        self.api = api
    
    def tiktok(self, url: str) -> dict:
        return self.api.make_request('post', '/scrape/tiktok', url=url)
    
    def tiktokv2(self, url: str) -> dict:
        return self.api.make_request('post', '/scrape/tiktokv2', url=url)
    
    def facebook(self, url: str) -> dict:
        return self.api.make_request('post', '/scrape/facebook', url=url)
    
    def instagram(self, url: str) -> dict:
        return self.api.make_request('post', '/scrape/instagram', url=url)
    
    def instagramv2(self, url: str) -> dict:
        return self.api.make_request('post', '/scrape/instagramv2', url=url)

    def twitter(self, url: str) -> dict:
        return self.api.make_request('post', '/scrape/twitter', url=url)
    
    def twitterv2(self, url: str) -> dict:
        return self.api.make_request('post', '/scrape/twitterv2', url=url)
    
    def likee(self, url: str) -> dict:
        return self.api.make_request('post', '/scrape/likee', url=url)
    
    def pinterest(self, url: str) -> dict:
        return self.api.make_request('post', '/scrape/pinterest', url=url)
    
    def pinterestv2(self, url: str) -> dict:
        return self.api.make_request('post', '/scrape/pinterestv2', url=url)
    
    def terabox(self, url: str) -> dict:
        return self.api.make_request('post', '/scrape/terabox', url=url)
    
    def gofile(self, url: str) -> dict:
        return self.api.make_request('post', '/scrape/gofile', url=url)
    
    def krakenfiles(self, url: str) -> dict:
        return self.api.make_request('post', '/scrape/krakenfiles', url=url)
    
    def yifysubtitles(self, imdb_id: str, lang: str) -> dict:
        return self.api.make_request('post', '/scrape/yifysubtitles', imdb_id=imdb_id, lang=lang)
    
    def filelions(self, url: str) -> dict:
        return self.api.make_request('post', '/scrape/filelions', url=url)
    
    def streamwish(self, url: str) -> dict:
        return self.api.make_request('post', '/scrape/streamwish', url=url)

    def icons8(self, url: str) -> dict:
        return self.api.make_request('post', '/scrape/icons8', url=url)
    
    def readlightnovel(self, title: str) -> dict:
        return self.api.make_request('post', '/scrape/readlightnovel', title=title)
    
    def reddit(self, url: str) -> dict:
        return self.api.make_request('post', '/scrape/reddit', url=url)
    
    def proxy(self, type: str) -> dict:
        return self.api.make_request('post', '/scrape/proxy', type=type)


#  MIT License

#  Copyright (c) 2023 X-Noid

#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:

#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.

#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.

from requests import get, post
from .features import Bypass, Scrape, Translate, Music, Ai


class NoidAPI:
    
    def __init__(self) -> None:
        self.bypass = Bypass(self)
        self.scrape = Scrape(self)
        self.translate = Translate(self)
        self.music = Music(self)
        self.ai = Ai(self)
        self.api_key = 'api-key'
        self.base_url = 'https://api.xgorn.pp.ua'
    
    def make_request(self, method: str, endpoint: str, **kwargs) -> dict:
        kwargs['api_key'] = self.api_key
        if self.api_key == 'api-key':
            return {'error': True, 'message': 'Invalid API key'}
        if method == 'get':
            return get(self.base_url+endpoint, params=kwargs).json()
        elif method == 'post':
            files = {}
            if kwargs.get('file'):
                files['file'] = open(kwargs['file'], 'rb')
                del kwargs['file']
            return post(self.base_url+endpoint, data=kwargs, files=files).json()
        else:
            return {'error': True, 'message': 'Invalid method'}


#  MIT License

#  Copyright (c) 2023 X-Noid

#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:

#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.

#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.

import re
from setuptools import setup, find_packages


with open('xgorn_api/__init__.py', encoding='utf-8') as f:
    version = re.findall(r'__version__ = \'(.+)\'', f.read())[0]


with open('xgorn_api/api.py', encoding='utf-8') as f:
    base_url = re.findall(r'self\.base_url = \'(.+)\'', f.read())[0]
    base_url_ = base_url.replace("https://", "")


with open('README.md', encoding='utf-8') as f:
    readme = f.read()


setup(
    name='xgorn-api',
    version=version,
    description=f'API Interface for {base_url_}',
    long_description=readme,
    long_description_content_type='text/markdown',
    url='https://github.com/X-Gorn/xgorn-api',
    author='xgorn',
    license='MIT',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Topic :: Internet',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
    keywords='api scraper bypasser translator client library python',
    project_urls={
        'Web': base_url,
        'Documentation': base_url+'/docs'
    },
    python_requires='~=3.7',
    packages=find_packages(),
    install_requires=[
        'requests'
    ],
)